@@ -2,7 +2,12 @@ from moodle_dl.moodle_connector.request_helper import RequestHelper
 
 
 def obtain_login_token(
-    username: str, password: str, moodle_domain: str, moodle_path: str = '/', skip_cert_verify: bool = False
+    username: str,
+    password: str,
+    moodle_domain: str,
+    moodle_path: str = '/',
+    skip_cert_verify: bool = False,
+    use_http: bool = False,
 ) -> str:
     """
     Send the login credentials to the Moodle-System and extracts the resulting Login-Token.
@@ -12,7 +17,9 @@ def obtain_login_token(
     """
     login_data = {'username': username, 'password': password, 'service': 'moodle_mobile_app'}
 
-    response = RequestHelper(moodle_domain, moodle_path, skip_cert_verify=skip_cert_verify).get_login(login_data)
+    response = RequestHelper(
+        moodle_domain, moodle_path, skip_cert_verify=skip_cert_verify, use_http=use_http
+    ).get_login(login_data)
 
     if 'token' not in response:
         # = we didn't get an error page (checked by the RequestHelper) but
